@@ -20,7 +20,8 @@ $REPO = "file://localhost$REPOFN";
 
 mkdir 'test_dir',0777;
 
-$ENV{LANG} = "en_US";  # Otherwise expect's will blow up
+$ENV{LANG} = "C";
+$ENV{LC_ALL} = "C";  # Otherwise expect's will blow up
 
 if (!$ENV{HARNESS_ACTIVE}) {
     use lib '.';
